function A=randisdd(I,N,d,varargin)
% FUNCTION fc_amat.random.randisdd
% -- fc_amat.random.randisdd(Imax,N,d)
%      Returns a N-by-d-by-d amat object whose matrices are strictly diagonally
%      dominant with non zeros elements drawn from discrete uniform 
%      distribution on 1:Imax.
%
% -- fc_amat.random.randisdd([Imin,Imax],N,d)
%      Returns a N-by-d-by-d amat object whose matrices are strictly diagonally
%      dominant with non zeros elements drawn from discrete uniform 
%      distribution on Imin:Imax.
%      
% -- fc_amat.random.randisdd(...,key,value)
%      Optional key/value pairs arguments are available with keys:
%        - 'complex', if value is true the amat object is complex 
%                     (default false i.e real amat object)
%        - 'class', values are those of Matlab randi function
%
%      See also: fc_amat.random.randtril, fc_amat.random.randntril,
%                class amat, randi
%
  p = inputParser;
  p.addParamValue('class','double',@ischar); 
  p.addParamValue('complex',false,@islogical);
  p.parse(varargin{:});
  R=p.Results;
  s=-3+2*randi(2,N,d,R.class); % sign 
  if R.complex
    A=complex(fc_amat.random.randi(I,N,d,d,R.class),fc_amat.random.randi(I,N,d,d,R.class));
    si=-3+2*randi(2,N,d,R.class); % sign imaginary part
    tmp=1+squeeze(sum(abs(double(A)),2)); % N-by-d , abs don't work with complex integer, so convert to double
    conv=eval(sprintf('@(x) %s(x);',R.class));
    for i=1:d
      x=rand(N,1);y=sqrt(1-x.*x);
      A(i,i)=complex((conv(round(x.*tmp(:,i)))+1).*s(:,i),(conv(round(y.*tmp(:,i)))+1).*si(:,i));
    end
  else
    A=fc_amat.random.randi(I,N,d,d,R.class);
    tmp=1+squeeze(sum(abs(A),2)); % N-by-d
    for i=1:d
      A(i,i)=tmp(:,i).*s(:,i);
    end
  end
end
